** Jeffrey Clemens and Michael Wither 5.11.2017
** Desciption: Clean and Analyze SIPP Data for "Additional Evidence and 
** Replication Code for Analyzing the Effects of Minimum Wage Increases 
** Enacted During the Great Recession"

** Notes: Running this file requires the following data sets:
** 1) sippl08puw`i'.dta for i=1/15 (available through NBER)
** See: http://www.nber.org/data/survey-of-income-and-program-participation-sipp-data.html
** The files sippl08puw`i'.dta are produced by downloading l08puw`i'.dat and 
** running 08w`i'.do and 08w`i'.dct within the required directory structure.
** 2) Macro_Controls.dta
** The file Macro_Controls.dta is available either through the replication packet in 
** which you have obtained this .do file or, as needed, from Jeffrey Clemens. 
** The file contains an FHFA median house price index which, as of 5/11/2017,
** could be downloaded directly from:
** https://www.fhfa.gov/DataTools/Downloads/Documents/HPI/HPI_AT_state.csv
** Note that the median house price index is the only variable from Macro_Controls.dta
** that is required to estimate the "baseline" specification.  Additional control
** variables in Macro_Controls.dta include standard state level data on the employment
** rate, the unemployment rate, and personal income per capita.  The employment
** series are available through the Bureau of Labor Statistics and the personal
** income series is available through the Bureau of Economic Analysis.
** 3) ConstructionBEAForMerge.dta
** This data set contains construction output data from the Bureau of Economic
** Analysis. Like Macro_Controls.dta, it is available either through the replication 
** packet in which you have obtained this .do file or, as needed, from Jeffrey Clemens.
** 4) MinimumWageRatesByStateAndMonth
** This is a modestly revised version of the minimum wage panel from the replication
** materials associated with "Effects of the Minimum Wage on Employment Dynamics" by
** Jonathan Meer and Jeremy West (JHR, 2016).  Note that only states' January 2008
** minimum wage rates are needed to replicate our "baseline" specification.
** These minimum wage rates can, as of 5/11/2017, be found at the following link 
** from the Bureau of Labor Statistics: https://www.dol.gov/whd/state/stateMinWageHis.htm


*==================================================
*===== Initial Set Up =====
*==================================================
clear all
set memory 3500m
set more off

* Set up directory structure
global sippdatadirectory C:\Users\jpc3385\Dropbox\Min Wage\Raw_SIPP_Data\sipp\2008
global workdirectory C:\Users\jpc3385\Dropbox\Min Wage\ZippererRebutallPaper\AdditionalEvidenceReplicationArchive
global logdirectory C:\Users\jpc3385\Dropbox\Min Wage\ZippererRebutallPaper\AdditionalEvidenceReplicationArchive
global additionaldatadirectory C:\Users\jpc3385\Dropbox\Min Wage\ZippererRebutallPaper\AdditionalEvidenceReplicationArchive
global resultsdirectory C:\Users\jpc3385\Dropbox\Min Wage\ZippererRebutallPaper\AdditionalEvidenceReplicationArchive\Results

cd "${workdirectory}"

capture log close
log using "${logdirectory}/AnalysisOfAlternateWageConstructionB.log", replace



*==================================================
*===== Load SIPP Waves =====
*==================================================
clear

forvalues i=1/15 {
preserve
use "${sippdatadirectory}/sippl08puw`i'.dta", clear
keep ewelac* ersend* erendb* eenrlm eunion1 ersnowrk eptwrk ejbhrs1 rmwkwjb rwksperm rpyper1 ecflag ebuscntr tsbdate1 tebdate1 ejobcntr tfipsst tftotinc rfnkids ulftmain efnp ejbind1 thtrninc eeducate rhcalyr rhcalmn thtotinc thearn ehhnumpp tpearn tptotinc ejbhrs1 rfpov ssuid shhadid eentaid epppnum ehrefper rfid ems tage wpfinwgt renroll esex epayhr1 tpyrate1 tpmsum1 epdjbthn eptwrk ehrsall rmesr rmwkwjb rmhrswk
compress
save "${sippdatadirectory}/temp.dta", replace
restore
append using "${sippdatadirectory}/temp.dta"
}

erase "${sippdatadirectory}/temp.dta"


*==================================================
*===== Rename Variables =====
*==================================================
destring epppnum, replace
rename rhcalyr year
rename rhcalmn month
rename tfipsst statefip
order statefip year month

*==================================================
*===== Add Macroeconomics Controls =====
*==================================================
merge m:1 statefip year month using "${additionaldatadirectory}/Macro_Controls.dta", nogenerate
replace index = index/1000
replace unemployment_rate = unemployment_rate/100
replace personal_income = personal_income/1000

gen quarter = 1
replace quarter = 2 if month >= 4 & month <= 6
replace quarter = 3 if month >= 7 & month <= 9
replace quarter = 4 if month >= 10 & month <= 12
merge m:1 statefip year quarter using "${additionaldatadirectory}/ConstructionBEAForMerge.dta"
keep if _merge != 2 
drop _merge
replace construction = construction/100

*==================================================
*===== Initial Cleaning =====
*==================================================
egen personid = group(ssuid epppnum)
drop if missing(personid)

drop if tage>=65
drop if tage<16

gen time = 100*year+month
drop if time<=200807
drop if time>201207

foreach inc in tpearn {
replace `inc' = `inc'/CPI
replace `inc' = 0 if `inc'<0
replace `inc' = 7500 if `inc' > 7500 & `inc' != .
}

egen personidcount = count(personid), by(personid)



*===================================================================
*===== Identify Bound States and Construct Treatment Variables =====
*===================================================================
preserve 
use "${additionaldatadirectory}/MinimumWageRatesByStateAndMonth.dta", clear
keep if year==2008 & month==1
keep statefip mw
replace mw = round(mw,.01)
rename mw mw2008
save "${additionaldatadirectory}/Jan2008MWs.dta", replace
restore
merge m:1 statefip using "${additionaldatadirectory}/Jan2008MWs.dta", nogenerate

gen Treatment = mw2008<6.55

gen Post = time>=200908
gen Post1 = time>=200908 & time<=201007
gen Post2 = time>=201008
gen Transition = time>=200905 & time<=200907
gen Period = 0
replace Period = 1 if Transition==1
replace Period = 2 if Post1==1
replace Period = 3 if Post2==1

gen Treatment_Post = Treatment*Post
gen Treatment_Post_1 = Treatment*Post1
gen Treatment_Post_2 = Treatment*Post2
gen Treatment_Trans = Treatment*Transition

*==================================================
*===== Outcome Variables =====
*==================================================
gen employed = rmesr >= 1 & rmesr <= 5
gen noearn = employed==0 | tpmsum1==0
gen intern = employed==1 & tpmsum1==0


*==============================================================
*== Create wage and average baseline wage variables ====
*==============================================================
gen hours = ehrsall
replace hours = 0 if ehrsall<0
gen tothours = hours*rmwkwjb

gen hourwage = tpearn/tothours if ejobcntr >=0
gen hrwage = tpyrate1 if ejobcntr >=0
replace hrwage = hourwage if tpyrate1==0 & !missing(hourwage) 
replace hrwage = round(hrwage,.01)
gen affectedwage = hrwage>=5.15 & hrwage<7.25

gen hourwagealt = tpearn/tothours if employed ==1
gen hrwagealt = tpyrate1 if employed == 1
replace hrwagealt = hourwagealt if tpyrate1==0 & !missing(hourwagealt) 
replace hrwagealt = round(hrwagealt,.01)

gen hrwagealtB = tpyrate1 if ejobcntr >=0 & tpyrate1 != 0
replace hrwagealtB = round(hrwagealtB,.01)

gen wagevar = hrwage if  Post==0
egen avewage = mean(wagevar), by(personid)

gen wagevaralt = hrwagealt if  Post==0
egen avewagealt = mean(wagevaralt), by(personid)

gen wagevaraltB = hrwagealtB if  Post==0
egen avewagealtB = mean(wagevaraltB), by(personid)

gen basemployedvar = employed if Post == 0
egen basemployed = max(basemployedvar), by(personid)

*==================================================
*== Create Target Samples
*==================================================
*** First grouping uses the baseline approach.
gen group = 0 if avewage== .
replace group = 1 if avewage<7.50
replace group = 2 if avewage>=7.50 & avewage <8.50
replace group = 3 if avewage>=8.50 & avewage <10.00
replace group = 4 if avewage>=10.00 & avewage != . 

*** Second version substitutes "employed" for "ejobcntr" in constructing
*** the wage variables.  Note that this introduces many 0s that come as the 
*** value of tpyrate1 for individuals for whom employed == 1 but who are not
*** in the universe for tpyrate1 because ejobcntr < 0.
gen groupalt = 0 if avewagealt== .
replace groupalt = 1 if avewagealt<7.50
replace groupalt = 2 if avewagealt>=7.50 & avewagealt <8.50
replace groupalt = 3 if avewagealt>=8.50 & avewagealt <10.00
replace groupalt = 4 if avewagealt>=10.00 & avewagealt != . 

*** Third version uses ejobcntr but throws out the imputations of earnings 
*** for those who are not paid at hourly rates.
gen groupaltB = 0 if avewagealtB== .
replace groupaltB = 1 if avewagealtB<7.50
replace groupaltB = 2 if avewagealtB>=7.50 & avewagealtB <8.50
replace groupaltB = 3 if avewagealtB>=8.50 & avewagealtB <10.00
replace groupaltB = 4 if avewagealtB>=10.00 & avewagealtB != . 


*==================================================
*== Diagnostic Information on Wage and Employment
*==================================================
sum hourwage hourwagealt
tab ejobcntr employed
tab rmesr if employed == 1 & ejobcntr == -1
sum tpyrate1 tpearn if employed == 1 & ejobcntr == -1

tab group if personidcount>=36
tab groupalt if personidcount>=36

tab group groupalt if personidcount>=36

tab ejobcntr employed
sum hrwage if ejobcntr < 0 & employed == 1, detail
sum hrwagealt if ejobcntr < 0 & employed == 1, detail

sum hrwage if group == 1 & groupalt != 1, detail
sum hrwagealt if group == 1 & groupalt != 1, detail

sum hrwage if group != 1 & groupalt == 1, detail
sum hrwagealt if group != 1 & groupalt == 1, detail

tab ejobcntr if group != 1 & groupalt == 1


*==================================================
*===== Demographic Variables =====
*==================================================
egen minage = min(tage), by(personid)
egen maxedu = max(eeducate), by(personid)
egen maxkids = max(rfnkids), by(personid)
gen morehs = maxedu>39


*==================================================================
*===== Additional Variables Needed For Analysis =====
*==================================================================
preserve
use "${additionaldatadirectory}/MinimumWageRatesByStateAndMonth.dta", clear
keep if year==2009 & month==1
keep statefip mw
replace mw = round(mw,.01)
rename mw mw2009
save "${additionaldatadirectory}/Jan2009MWs.dta", replace
restore
merge m:1 statefip using "${additionaldatadirectory}/Jan2009MWs.dta", nogenerate

egen modebaselinemwB = mode(mw2009) if Post == 0, by(personid) maxmode
egen modebaselinemw = max(modebaselinemwB), by(personid)

xtile wagepctileTalt = avewagealt if Treatment == 1, n(100) 
xtile wagepctileCalt = avewagealt if Treatment == 0, n(100) 
gen wagepctilealt = wagepctileCalt if Treatment == 0
replace wagepctilealt = wagepctileTalt if Treatment == 1 & wagepctilealt == .

xtile wagepctileT = avewage if Treatment == 1, n(100) 
xtile wagepctileC = avewage if Treatment == 0, n(100) 
gen wagepctile = wagepctileC if Treatment == 0
replace wagepctile = wagepctileT if Treatment == 1 & wagepctile == .


gen subsubminwage = .
replace subsubminwage = 0 if employed == 1 & Post == 0
replace subsubminwage = 1 if hrwage < .9*modebaselinemw & employed == 1 & Post == 0
gen nearminwage = .
replace nearminwage = 0 if employed == 1 & Post == 0
replace nearminwage = 1 if hrwage >= .9*modebaselinemw & hrwage < 1.2*modebaselinemw & employed == 1 & Post == 0


*==================================================================
*===== Baseline Regressions =====
*==================================================================
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)

areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)

areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)




*==================================================================
*===== Various Group 1 Options  =====
*==================================================================
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAlt", replace

areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index personal_income unemployment_rate construction if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedMoreMacroGroup1SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index personal_income unemployment_rate construction if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedMoreMacroGroup1SIPPPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index personal_income unemployment_rate construction if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedMoreMacroGroup1SIPPNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index personal_income unemployment_rate construction if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedMoreMacroGroup1SIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index personal_income unemployment_rate construction if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedMoreMacroGroup1SIPPAlt", replace



areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAlt", replace

areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPWt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPPctileWt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPNearMinWt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltBWt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltWt", replace

areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPP", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPPctile", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPNearMin", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPAltB", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPAlt", replace

areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPWt", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPPctileWt", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPNearMinWt", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPAltBWt", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index [aw = wpfinwgt] if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPAltWt", replace

areg affectedwage Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/AffectedGroup1SIPP", replace
areg affectedwage Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/AffectedGroup1SIPPPctile", replace
areg affectedwage Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > 0 & avewage <= modebaselinemw + .5 &  personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/AffectedGroup1SIPPNearMin", replace
areg affectedwage Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/AffectedGroup1SIPPAltB", replace
areg affectedwage Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/AffectedGroup1SIPPAlt", replace



*==================================================================
*===== Groups Defined Using Alternative Wage Measures =====
*==================================================================
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==0 & basemployed == 0 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0SIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==0 & basemployed == 1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0SalSIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==2 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2SIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==3 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3SIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==4 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4SIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if (groupaltB==1 | (groupaltB == 0 & minage <= 21 & basemployed == 0)) & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1YoungSIPPAltB", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if (groupaltB==1 | groupaltB == 0 & basemployed == 0) & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1AllUnempSIPPAltB", replace

areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==0 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0SIPPAlt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAlt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==2 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2SIPPAlt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==3 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3SIPPAlt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==4 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4SIPPAlt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if (groupalt==1 | (groupalt == 0 & minage <= 21)) & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1YoungSIPPAlt", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if (groupalt==1 | groupalt == 0) & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1AllUnempSIPPAlt", replace

areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==0 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==2 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==3 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==4 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4SIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if (group==1 | (group == 0 & minage <= 21)) & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1YoungSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if (group==1 | group == 0) & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1AllUnempSIPP", replace



*===========================================================================
*===== Alt. Groups And Groups Defined Using Alternative Wage Measures =====
*===========================================================================
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt == . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0SIPPAltPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctilealt <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctilealt > 13 & wagepctilealt <= 35 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2SIPPAltPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctilealt > 35 & wagepctilealt <= 60 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3SIPPAltPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctilealt > 60  & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4SIPPAltPctile", replace

areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage == . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0SIPPPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile > 13 & wagepctile <= 35 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2SIPPPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile > 35 & wagepctile <= 60 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3SIPPPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile > 60  & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4SIPPPctile", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if (avewage == . | wagepctile <= 13) & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1AllUnempSIPPPctile", replace

areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt == . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0SIPPAltNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt > 0 & avewagealt <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt > modebaselinemw + 0.5 & avewagealt <= modebaselinemw + 3 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2SIPPAltNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt > modebaselinemw + 3 & avewagealt <= modebaselinemw + 5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3SIPPAltNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt > modebaselinemw + 5 & avewagealt != . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4SIPPAltNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if (avewagealt == . | avewagealt > 0 & avewagealt <= modebaselinemw + .5) & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1AllUnempSIPPAltNearMin", replace

areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage == . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0SIPPNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > modebaselinemw + .5 & avewage <= modebaselinemw + 3 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2SIPPNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > modebaselinemw + 3 & avewage <= modebaselinemw + 5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3SIPPNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > modebaselinemw + 5 & avewage != . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4SIPPNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if (avewage == . | avewage > 0 & avewage <= modebaselinemw + .5) & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1AllUnempSIPPNearMin", replace


areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealtB == . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup0SIPPAltBNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealtB > 0 & avewagealtB <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltBNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealtB > modebaselinemw + 0.5 & avewagealtB <= modebaselinemw + 3 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2SIPPAltBNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealtB > modebaselinemw + 3 & avewagealtB <= modebaselinemw + 5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3SIPPAltBNearMin", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealtB > modebaselinemw + 5 & avewagealtB != . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup4SIPPAltBNearMin", replace

areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage == . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup0SIPPNearMin", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPNearMin", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > modebaselinemw + .5 & avewage <= modebaselinemw + 3 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup2SIPPNearMin", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > modebaselinemw + 3 & avewage <= modebaselinemw + 5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup3SIPPNearMin", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > modebaselinemw + 5 & avewage != . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup4SIPPNearMin", replace

areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt == . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup0SIPPAltNearMin", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt > 0 & avewagealt <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPAltNearMin", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt > modebaselinemw + .5 & avewagealt <= modebaselinemw + 3 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup2SIPPAltNearMin", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt > modebaselinemw + 3 & avewagealt <= modebaselinemw + 5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup3SIPPAltNearMin", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewagealt > modebaselinemw + 5 & avewagealt != . & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup4SIPPAltNearMin", replace



*** Alternative Sample Inclusion Criteria (Employed)
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group== 1 & personidcount >= 12, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/InclusionLax1Employed", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group== 1 & personidcount >= 24, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/InclusionLax2Employed", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group== 1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/InclusionLax3Employed", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group== 1 & personidcount == 48, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/InclusionLax4Employed", replace


*** Alternative Sample Inclusion Criteria (No earnings)
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group== 1 & personidcount >= 12, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/InclusionLax1Noearn", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group== 1 & personidcount >= 24, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/InclusionLax2Noearn", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group== 1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/InclusionLax3Noearn", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group== 1 & personidcount == 48, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/InclusionLax4Noearn", replace




*==================================================
*** Summary statistics
*==================================================
label variable affectedwage "Wage \\$5.15-\\$7.25"
label variable noearn "No Earnings"
label variable employed "Employed"
label variable intern "Unpaid Work"
label variable ehrsall "Hours Worked/week"
label variable tptotinc "Income"
label variable minage "Age"
label variable rfnkids "Num. of Children"
label variable morehs "More than H.S. Deg."
label variable subsubminwage "Wage less than 0.9 x Min."
label variable nearminwage "Wage btw 0.9 and 1.2 x Min."
gen infood = (ejbind1>=8660 & ejbind1 <=8690)

set more off
capture eststo clear
bysort Treatment: eststo: estpost tabstat affectedwage subsubminwage nearminwage employed intern ehrsall morehs minage if group == 1 & personidcount >= 36 & Post == 0, ///
	columns(statistics) statistics(mean sd)
bysort Treatment: eststo: estpost tabstat affectedwage subsubminwage nearminwage employed intern ehrsall morehs minage if groupalt == 1 & personidcount >= 36 & Post == 0, ///
	columns(statistics) statistics(mean sd)
bysort Treatment: eststo: estpost tabstat affectedwage subsubminwage nearminwage employed intern ehrsall morehs minage if groupaltB == 1 & personidcount >= 36 & Post == 0, ///
	columns(statistics) statistics(mean sd)
bysort Treatment: eststo: estpost tabstat affectedwage subsubminwage nearminwage employed intern ehrsall morehs minage if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36 & Post == 0, ///
	columns(statistics) statistics(mean sd)
bysort Treatment: eststo: estpost tabstat affectedwage subsubminwage nearminwage employed intern ehrsall morehs minage if avewage != . & wagepctile <= 13 & personidcount >= 36 & Post == 0, ///
	columns(statistics) statistics(mean sd)
	
esttab using "${resultsdirectory}/SumStatsAlternativeTargetDefs.tex", replace main(mean) aux(sd) label nomtitle nolegend nonotes
capture eststo clear

gen PeriodSIPP = ""
replace PeriodSIPP = "base" if Period == 0
replace PeriodSIPP = "post" if Period == 2 | Period == 3

bysort Treatment PeriodSIPP: eststo: estpost tabstat employed if group == 1 & personidcount >= 36, ///
	columns(statistics) statistics(mean sd)
bysort Treatment PeriodSIPP: eststo: estpost tabstat employed if groupalt == 1 & personidcount >= 36, ///
	columns(statistics) statistics(mean sd)
bysort Treatment PeriodSIPP: eststo: estpost tabstat employed if groupaltB == 1 & personidcount >= 36, ///
	columns(statistics) statistics(mean sd)
bysort Treatment PeriodSIPP: eststo: estpost tabstat employed if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, ///
	columns(statistics) statistics(mean sd)
bysort Treatment PeriodSIPP: eststo: estpost tabstat employed if avewage != . & wagepctile <= 13 & personidcount >= 36, ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}/SumStatsLowSkilledEmploymentDefs.tex", replace main(mean) label nomtitle nolegend nonotes
esttab using "${resultsdirectory}/SumStatsLowSkilledEmploymentDefs.csv", replace main(mean) label nomtitle nolegend nonotes
capture eststo clear




*==================================================
***** Attrition and panel balance analysis
*==================================================
drop if month == .
gen event = .
replace event = -7 + month if year==2008
replace event = 5 + month if year==2009
replace event = 17 + month if year==2010
replace event = 29 + month if year==2011
replace event = 41 + month if year==2012

gen Target = group==1

drop if event == .
drop if personid == .

tsset personid event
tsfill, full


*** Begin process of filling in values for variables needed in the regression specifications
bysort personid: carryforward group, replace
bysort personid: carryforward Target, replace

egen modegroup = mode(group), by(personid) maxmode
replace group = modegroup if group == .
egen modeTarget = mode(Target), by(personid) maxmode
replace Target = modeTarget if Target == .



*** Fill in state under the assumption that missing values take the same value as 
*** the modal value during the baseline period
*egen modestatefip = mode(statefip), by(personid) maxmode
egen modestatefipB = mode(statefip) if Period <= 1, by(personid) maxmode
egen modestatefip = max(modestatefipB),  by(personid) 
replace statefip = modestatefip if statefip == .


*** Individuals primarily employed in a particular industry at baseline
gen ejbind = ejbind1 if time<200908
replace ejbind = . if ejbind == - 1 
egen industry = mode(ejbind), maxmode by(personid)

gen industry2B = industry/100
gen industry2 = floor(industry2B)


*** Set up time variables
egen modemonth = mode(month), by(event) maxmode
replace month = modemonth if month == .
gen yrmthB = ym(year, month) 
egen yrmth = max(yrmthB), by(event)
format yrmth %tmMon,YY
fvset base 590 yrmth  
fvset report yrmth 

egen yearmax = max(year), by(event)
replace year = yearmax if year == .


*** Drop a set of variables that are no longer needed
drop ebuscntr-ewelact4


*** Fill in missing values of variables included in the regressions on the basis of 
*** whether they vary at the state, year, state-year, or state-year-group level
egen modeTreatment = mode(Treatment), by(statefip) maxmode
egen modePeriod = mode(Period), by(event) maxmode
egen modeTreatment_Post_1 = mode(Treatment_Post_1), by(statefip event) maxmode
egen modeTreatment_Post_2 = mode(Treatment_Post_2), by(statefip event) maxmode
egen modeTreatment_Trans = mode(Treatment_Trans), by(statefip event) maxmode
egen modeindex = mode(index), by(statefip event) maxmode

replace Treatment = modeTreatment if Treatment == .
replace Period = modePeriod if Period == .
replace Treatment_Post_1 = modeTreatment_Post_1 if Treatment_Post_1 == .
replace Treatment_Post_2 = modeTreatment_Post_2 if Treatment_Post_2 == .
replace Treatment_Trans = modeTreatment_Trans if Treatment_Trans == .
replace index = modeindex if index == .


*** Basic correlation between the "Treatment" state indicator and the incidence of "missing" data
gen missing = 0
replace missing = 1 if noearn == .

cor missing Treatment
reg missing Treatment, cluster(statefip)

cor missing Treatment if group == 1
reg missing Treatment if group == 1, cluster(statefip)

areg missing Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.yrmth index if group==1, absorb(personid) cluster(statefip)



areg employed i.Treatment##i.yrmth i.statefip index if group==1, absorb(personid) cluster(statefip)
parmest,format(estimate min95 max95 %8.0f p %8.1e) saving("${resultsdirectory}/EmploymentDynamicsForAttritionFigure.dta", replace)
areg noearn i.Treatment##i.yrmth i.statefip index if group==1, absorb(personid) cluster(statefip)
parmest,format(estimate min95 max95 %8.0f p %8.1e) saving("${resultsdirectory}/NoEarnDynamicsForAttritionFigure.dta", replace)
areg missing i.Treatment##i.yrmth i.statefip index if group==1, absorb(personid) cluster(statefip)
parmest,format(estimate min95 max95 %8.0f p %8.1e) saving("${resultsdirectory}/MissingDynamicsForAttritionFigure.dta", replace)


*** Dynamic Attrition Figures
use "${resultsdirectory}/MissingDynamicsForAttritionFigure.dta", clear
rename estimate missingestimate
label var missingestimate "Prob. of Affected Wage"
rename min95  missingmin95
label var missingmin95 "Missing Lower"
rename max95  missingmax95
label var missingmax95 "Missing Upper"
drop dof t p stderr 

merge 1:1 parm using "${resultsdirectory}/NoEarnDynamicsForAttritionFigure.dta"
drop _merge dof t p stderr
rename estimate noearnestimate
label var noearnestimate "Prob. of No Earnings"
rename min95  noearnmin95
label var noearnmin95 "Second Stage Lower"
rename max95  noearnmax95
label var noearnmax95 "Second Stage Upper"

merge 1:1 parm using "${resultsdirectory}/EmploymentDynamicsForAttritionFigure.dta"
drop _merge dof t p stderr
rename estimate employedestimate
label var employedestimate "Prob. of Employment"
rename min95  employedmin95
label var employedmin95 "Second Stage Lower"
rename max95  employedmax95
label var employedmax95 "Second Stage Upper"


keep if substr(parm,1,11) == "1.Treatment"
replace parm = "1.Treatment#590.yrmth" if parm == "1.Treatment"
replace missingestimate = 0 if parm == "1.Treatment#590.yrmth"
replace missingmax95 = 0 if parm == "1.Treatment#590.yrmth"
replace missingmin95 = 0 if parm == "1.Treatment#590.yrmth"
replace employedestimate = 0 if parm == "1.Treatment#590.yrmth"
replace employedmax95 = 0 if parm == "1.Treatment#590.yrmth"
replace employedmin95 = 0 if parm == "1.Treatment#590.yrmth"
replace noearnestimate = 0 if parm == "1.Treatment#590.yrmth"
replace noearnmax95 = 0 if parm == "1.Treatment#590.yrmth"
replace noearnmin95 = 0 if parm == "1.Treatment#590.yrmth"

gen yrmthB = ""
replace yrmthB = substr(parm,13,15)
gen yrmthC = ""
replace yrmthC = substr(yrmthB,1,3)
destring yrmthC, gen(yrmth)
format yrmth %tmMon,YY

 graph twoway scatter employedestimate yrmth || ///
	rcap employedmin95 employedmax95 yrmth,  || ///
	scatter missingestimate yrmth  , msymbol(X) msize(medlarge) ///
 xline(594, lcolor(black)) xline(590, lcolor(black) lpattern(dash)) ///
 yline(0, lcolor(black)) ///
 title("Dynamics of Employment and Attrition Estimates", size(medlarge)) ///
 ylabel(-0.2 "-0.2" -0.1 "-0.1" 0.0 "0.0"  0.1 "0.1" 0.2 "0.2") ///
 legend(order(3 "Prob. of Missing" 1 "Prob. of Employment") rows(1)) ///
 xtitle("") ytitle("Change") graphregion(color(white)) /// 
 xlabel(582(12)630, labsize(medsmall)) xscale(range(582 631)) ///
 saving("${resultsdirectory}/DynamicemployedmissingDD.pdf", replace)  ///
 name(DynamicemployedmissingDD, replace)
 
	
	
 graph twoway scatter noearnestimate yrmth || ///
	rcap noearnmin95 noearnmax95 yrmth,  || ///
	scatter missingestimate yrmth  , msymbol(X) msize(medlarge) ///
 xline(594, lcolor(black)) xline(590, lcolor(black) lpattern(dash)) ///
 yline(0, lcolor(black)) ///
 title("Dynamics of No Earnings and Attrition Estimates", size(medlarge)) ///
 ylabel(-0.2 "-0.2" -0.1 "-0.1" 0.0 "0.0"  0.1 "0.1" 0.2 "0.2") ///
 legend(order(3 "Prob. of Missing" 1 "Prob. of No Earnings") rows(1)) ///
 xtitle("") ytitle("Change") graphregion(color(white)) /// 
 xlabel(582(12)630, labsize(medsmall)) xscale(range(582 631)) ///
 saving("${resultsdirectory}/DynamicnoearnmissingDD.pdf", replace)  ///
 name(DynamicnoearnmissingDD, replace)


capture log close
