** Jeffrey Clemens and Michael Wither 5.11.2017
** Desciption: Clean and Analyze SIPP Data for "Additional Evidence and 
** Replication Code for Analyzing the Effects of Minimum Wage Increases 
** Enacted During the Great Recession"

** Notes: Running this file requires the following data sets:
** 1) sippl08puw`i'.dta for i=1/15 (available through NBER)
** See: http://www.nber.org/data/survey-of-income-and-program-participation-sipp-data.html
** The files sippl08puw`i'.dta are produced by downloading l08puw`i'.dat and 
** running 08w`i'.do and 08w`i'.dct within the required directory structure.
** 2) Macro_Controls.dta
** The file Macro_Controls.dta is available either through the replication packet in 
** which you have obtained this .do file or, as needed, from Jeffrey Clemens. 
** The file contains an FHFA median house price index which, as of 5/11/2017,
** could be downloaded directly from:
** https://www.fhfa.gov/DataTools/Downloads/Documents/HPI/HPI_AT_state.csv
** Note that the median house price index is the only variable from Macro_Controls.dta
** that is required to estimate the "baseline" specification.  Additional control
** variables in Macro_Controls.dta include standard state level data on the employment
** rate, the unemployment rate, and personal income per capita.  The employment
** series are available through the Bureau of Labor Statistics and the personal
** income series is available through the Bureau of Economic Analysis.
** 3) ConstructionBEAForMerge.dta
** This data set contains construction output data from the Bureau of Economic
** Analysis. Like Macro_Controls.dta, it is available either through the replication 
** packet in which you have obtained this .do file or, as needed, from Jeffrey Clemens.
** 4) MinimumWageRatesByStateAndMonth
** This is a modestly revised version of the minimum wage panel from the replication
** materials associated with "Effects of the Minimum Wage on Employment Dynamics" by
** Jonathan Meer and Jeremy West (JHR, 2016).  Note that only states' January 2008
** minimum wage rates are needed to replicate our "baseline" specification.
** These minimum wage rates can, as of 5/11/2017, be found at the following link 
** from the Bureau of Labor Statistics: https://www.dol.gov/whd/state/stateMinWageHis.htm

*==================================================
*===== Initial Set Up =====
*==================================================

clear all
set memory 3500m
set more off

* Set up directory structure
global sippdatadirectory C:\Users\jpc3385\Dropbox\Min Wage\Raw_SIPP_Data\sipp\2008
global workdirectory C:\Users\jpc3385\Dropbox\Min Wage\ZippererRebutallPaper\AdditionalEvidenceReplicationArchive
global logdirectory C:\Users\jpc3385\Dropbox\Min Wage\ZippererRebutallPaper\AdditionalEvidenceReplicationArchive
global additionaldatadirectory C:\Users\jpc3385\Dropbox\Min Wage\ZippererRebutallPaper\AdditionalEvidenceReplicationArchive
global resultsdirectory C:\Users\jpc3385\Dropbox\Min Wage\ZippererRebutallPaper\AdditionalEvidenceReplicationArchive\Results

cd "${workdirectory}"

capture log close
log using "${logdirectory}/AnalysisOfAlternateWageConstructionBCleanAtEnd.log", replace



*==================================================
*===== Load SIPP Waves =====
*==================================================
clear

forvalues i=1/15 {
preserve
use "${sippdatadirectory}/sippl08puw`i'.dta", clear
keep ewelac* ersend* erendb* eenrlm eunion1 ersnowrk eptwrk ejbhrs1 rmwkwjb rwksperm rpyper1 ecflag ebuscntr tsbdate1 tebdate1 ejobcntr tfipsst tftotinc rfnkids ulftmain efnp ejbind1 thtrninc eeducate rhcalyr rhcalmn thtotinc thearn ehhnumpp tpearn tptotinc ejbhrs1 rfpov ssuid shhadid eentaid epppnum ehrefper rfid ems tage wpfinwgt renroll esex epayhr1 tpyrate1 tpmsum1 epdjbthn eptwrk ehrsall rmesr rmwkwjb rmhrswk
compress
save "${sippdatadirectory}/temp.dta", replace
restore
append using "${sippdatadirectory}/temp.dta"
}

erase "${sippdatadirectory}/temp.dta"


*==================================================
*===== Rename Variables =====
*==================================================
destring epppnum, replace
rename rhcalyr year
rename rhcalmn month
rename tfipsst statefip
order statefip year month

*==================================================
*===== Add Macroeconomics Controls =====
*==================================================
merge m:1 statefip year month using "${additionaldatadirectory}/Macro_Controls.dta", nogenerate
replace index = index/1000
replace unemployment_rate = unemployment_rate/100
replace personal_income = personal_income/1000

gen quarter = 1
replace quarter = 2 if month >= 4 & month <= 6
replace quarter = 3 if month >= 7 & month <= 9
replace quarter = 4 if month >= 10 & month <= 12
merge m:1 statefip year quarter using "${additionaldatadirectory}/ConstructionBEAForMerge.dta"
keep if _merge != 2 
drop _merge
replace construction = construction/100

*==================================================
*===== Initial Cleaning =====
*==================================================
egen personid = group(ssuid epppnum)
drop if missing(personid)

gen time = 100*year+month

egen personidcount = count(personid), by(personid)



*===================================================================
*===== Identify Bound States and Construct Treatment Variables =====
*===================================================================
preserve 
use "${additionaldatadirectory}/MinimumWageRatesByStateAndMonth.dta", clear
keep if year==2008 & month==1
keep statefip mw
replace mw = round(mw,.01)
rename mw mw2008
save "${additionaldatadirectory}/Jan2008MWs.dta", replace
restore
merge m:1 statefip using "${additionaldatadirectory}/Jan2008MWs.dta", nogenerate

gen Treatment = mw2008<6.55

gen Post = time>=200908
gen Post1 = time>=200908 & time<=201007
gen Post2 = time>=201008
gen Transition = time>=200905 & time<=200907
gen Period = 0
replace Period = 1 if Transition==1
replace Period = 2 if Post1==1
replace Period = 3 if Post2==1

gen Treatment_Post = Treatment*Post
gen Treatment_Post_1 = Treatment*Post1
gen Treatment_Post_2 = Treatment*Post2
gen Treatment_Trans = Treatment*Transition

*==================================================
*===== Outcome Variables =====
*==================================================
gen employed = rmesr >= 1 & rmesr <= 5
gen noearn = employed==0 | tpmsum1==0
gen intern = employed==1 & tpmsum1==0


*==============================================================
*== Create wage and average baseline wage variables ====
*==============================================================
gen hours = ehrsall
replace hours = 0 if ehrsall<0
gen tothours = hours*rmwkwjb

gen hourwage = tpearn/tothours if ejobcntr >=0
gen hrwage = tpyrate1 if ejobcntr >=0
replace hrwage = hourwage if tpyrate1==0 & !missing(hourwage) 
replace hrwage = round(hrwage,.01)
gen affectedwage = hrwage>=5.15 & hrwage<7.25

gen hourwagealt = tpearn/tothours if employed ==1
gen hrwagealt = tpyrate1 if employed == 1
replace hrwagealt = hourwagealt if tpyrate1==0 & !missing(hourwagealt) 
replace hrwagealt = round(hrwagealt,.01)

gen hrwagealtB = tpyrate1 if ejobcntr >=0 & tpyrate1 != 0
replace hrwagealtB = round(hrwagealtB,.01)

gen wagevar = hrwage if  Post==0
egen avewage = mean(wagevar), by(personid)

gen wagevaralt = hrwagealt if  Post==0
egen avewagealt = mean(wagevaralt), by(personid)

gen wagevaraltB = hrwagealtB if  Post==0
egen avewagealtB = mean(wagevaraltB), by(personid)

gen basemployedvar = employed if Post == 0
egen basemployed = max(basemployedvar), by(personid)

*==================================================
*== Create Target Samples
*==================================================
*** First grouping uses the baseline approach.
gen group = 0 if avewage== .
replace group = 1 if avewage<7.50
replace group = 2 if avewage>=7.50 & avewage <8.50
replace group = 3 if avewage>=8.50 & avewage <10.00
replace group = 4 if avewage>=10.00 & avewage != . 

*** Second version substitutes "employed" for "ejobcntr" in constructing
*** the wage variables.  Note that this introduces many 0s that come as the 
*** value of tpyrate1 for individuals for whom employed == 1 but who are not
*** in the universe for tpyrate1 because ejobcntr < 0.
gen groupalt = 0 if avewagealt== .
replace groupalt = 1 if avewagealt<7.50
replace groupalt = 2 if avewagealt>=7.50 & avewagealt <8.50
replace groupalt = 3 if avewagealt>=8.50 & avewagealt <10.00
replace groupalt = 4 if avewagealt>=10.00 & avewagealt != . 

*** Third version uses ejobcntr but throws out the imputations of earnings 
*** for those who are not paid at hourly rates.
gen groupaltB = 0 if avewagealtB== .
replace groupaltB = 1 if avewagealtB<7.50
replace groupaltB = 2 if avewagealtB>=7.50 & avewagealtB <8.50
replace groupaltB = 3 if avewagealtB>=8.50 & avewagealtB <10.00
replace groupaltB = 4 if avewagealtB>=10.00 & avewagealtB != . 


*==================================================
*== Diagnostic Information on Wage and Employment
*==================================================
sum hourwage hourwagealt
tab ejobcntr employed
tab rmesr if employed == 1 & ejobcntr == -1
sum tpyrate1 tpearn if employed == 1 & ejobcntr == -1

tab group if personidcount>=36
tab groupalt if personidcount>=36

tab group groupalt if personidcount>=36

tab ejobcntr employed
sum hrwage if ejobcntr < 0 & employed == 1, detail
sum hrwagealt if ejobcntr < 0 & employed == 1, detail

sum hrwage if group == 1 & groupalt != 1, detail
sum hrwagealt if group == 1 & groupalt != 1, detail

sum hrwage if group != 1 & groupalt == 1, detail
sum hrwagealt if group != 1 & groupalt == 1, detail

tab ejobcntr if group != 1 & groupalt == 1


*==================================================
*===== Demographic Variables =====
*==================================================
egen minage = min(tage), by(personid)
egen maxedu = max(eeducate), by(personid)
egen maxkids = max(rfnkids), by(personid)
gen morehs = maxedu>39


*==================================================================
*===== Additional Variables Needed For Analysis =====
*==================================================================
preserve
use "${additionaldatadirectory}/MinimumWageRatesByStateAndMonth.dta", clear
keep if year==2009 & month==1
keep statefip mw
replace mw = round(mw,.01)
rename mw mw2009
save "${additionaldatadirectory}/Jan2009MWs.dta", replace
restore
merge m:1 statefip using "${additionaldatadirectory}/Jan2009MWs.dta", nogenerate

egen modebaselinemwB = mode(mw2009) if Post == 0, by(personid) maxmode
egen modebaselinemw = max(modebaselinemwB), by(personid)

xtile wagepctileTalt = avewagealt if Treatment == 1, n(100) 
xtile wagepctileCalt = avewagealt if Treatment == 0, n(100) 
gen wagepctilealt = wagepctileCalt if Treatment == 0
replace wagepctilealt = wagepctileTalt if Treatment == 1 & wagepctilealt == .

xtile wagepctileT = avewage if Treatment == 1, n(100) 
xtile wagepctileC = avewage if Treatment == 0, n(100) 
gen wagepctile = wagepctileC if Treatment == 0
replace wagepctile = wagepctileT if Treatment == 1 & wagepctile == .


gen subsubminwage = .
replace subsubminwage = 0 if employed == 1 & Post == 0
replace subsubminwage = 1 if hrwage < .9*modebaselinemw & employed == 1 & Post == 0
gen nearminwage = .
replace nearminwage = 0 if employed == 1 & Post == 0
replace nearminwage = 1 if hrwage >= .9*modebaselinemw & hrwage < 1.2*modebaselinemw & employed == 1 & Post == 0

*==================================================================
*===== Final Cleaning at End  								  =====
*==================================================================

drop if tage>=65
drop if tage<16

drop if time<=200807
drop if time>201207

foreach inc in tpearn {
replace `inc' = `inc'/CPI
replace `inc' = 0 if `inc'<0
replace `inc' = 7500 if `inc' > 7500 & `inc' != .
}

*==================================================================
*===== Various Group 1 Options with cleaning commands at end  =====
*==================================================================
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPCleanEnd", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPPctileCleanEnd", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPNearMinCleanEnd", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltBCleanEnd", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1SIPPAltCleanEnd", replace

areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if group==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPCleanEnd", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if wagepctile <= 13 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPPctileCleanEnd", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if avewage > 0 & avewage <= modebaselinemw + .5 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPNearMinCleanEnd", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupaltB==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPAltBCleanEnd", replace
areg noearn Treatment_Post_1 Treatment_Post_2 Treatment_Trans i.statefip i.time index if groupalt==1 & personidcount >= 36, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/NoearnGroup1SIPPAltCleanEnd", replace


capture log close
